==> weka_3.6.6.orig.tar.gz: weka-3-6-6/src/test/java/weka/classifiers/meta/DecorateTest.java <==
/*
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * Copyright (C) 2005 University of Waikato, Hamilton, New Zealand
 */

package weka.classifiers.meta;

import weka.classifiers.AbstractClassifierTest;
import weka.classifiers.Classifier;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Tests Decorate. Run from the command line with:<p/>
 * java weka.classifiers.meta.DecorateTest
 *
 * @author FracPete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 1.2 $
 */
public class DecorateTest 
  extends AbstractClassifierTest {

  public DecorateTest(String name) { 
    super(name);  
  }

  /** Creates a default Decorate */
  public Classifier getClassifier() {
    return new Decorate();
  }

  public static Test suite() {
    return new TestSuite(DecorateTest.class);
  }

  public static void main(String[] args){
    junit.textui.TestRunner.run(suite());
  }
}

==> weka_3.6.10.orig.tar.gz: weka-3-6-10/src/test/java/weka/classifiers/meta/DecorateTest.java <==
/*
 *    This program is free software; you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation; either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with this program; if not, write to the Free Software
 *    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/*
 * Copyright (C) 2005 University of Waikato, Hamilton, New Zealand
 */

package weka.classifiers.meta;

import weka.classifiers.AbstractClassifierTest;
import weka.classifiers.Classifier;

import junit.framework.Test;
import junit.framework.TestSuite;

/**
 * Tests Decorate. Run from the command line with:<p/>
 * java weka.classifiers.meta.DecorateTest
 *
 * @author FracPete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 8036 $
 */
public class DecorateTest 
  extends AbstractClassifierTest {

  public DecorateTest(String name) { 
    super(name);  
  }

  /** Creates a default Decorate */
  public Classifier getClassifier() {
    Decorate d = new Decorate();
    d.setNumIterations(10);
    d.setDesiredSize(10);
    return d;
  }

  public static Test suite() {
    return new TestSuite(DecorateTest.class);
  }

  public static void main(String[] args){
    junit.textui.TestRunner.run(suite());
  }
}
